Project.Prediction.DataCollection module — HAX712X-DOS 1.0.0 documentation

# Project.Prediction.DataCollection module

class Project.Prediction.DataCollection.Data(data=Empty DataFrame Columns: [] Index: [])

  Bases: `object`

  This class is for downloading the data from 2012 into 2022 and fil out all the missing values

  impo()

    This Method is for importing data from the package: this data is alrady clean and filtered by using the dataDownload method

    Returns

      to a data trining that will be imported after to train our Model forcast.

    Return type

      DataFrame

  dataDownload()

    This method is for download the data from 2019 to 2022 year by year.

  Filnan()

    In this Method we have fill the nan by the mean of two successive observation:

    Warning

    If you use dataDownloadThis() method then it’s very important to call this method directly, otherwise you will get the data full of nan values.